@@ -1,7 +1,5 @@
 package Quiki;
 
-use feature ':5.10';
-
 use Data::Dumper;
 
 use Quiki::Formatter;
@@ -26,11 +24,11 @@ Quiki - A lightweight Wiki in Perl
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 
 =head1 SYNOPSIS
@@ -206,7 +204,7 @@ sub run {
     # XXX
     if ($action eq 'save' && param("submit_opt") eq "Save") {
         if (Quiki::Pages->locked_for_user($node, $self->{sid})) {
-            my $text = param('text') // '';
+            my $text = defined(param('text')) ? param('text') : '';
             Quiki::Pages->check_in($self, $node, $text);
             Quiki::Pages->unlock($node);
             $self->_msg("Content for \"$node\" updated.");
@@ -278,7 +276,7 @@ sub run {
                      BREADCUMBS  => $breadcumbs,
                      SERVERNAME  => $self->{SERVER_NAME},
                      DOCROOT     => $self->{DOCROOT},
-                     OPENSITE    => $self->{opensite} // 1,
+                     OPENSITE    => defined($self->{opensite}) ? $self->{opensite} : 1,
                      USER_ROLE   => $urole,
                      PREVIEW     => $preview,
                     );
@@ -290,7 +288,8 @@ sub run {
 
     if ($action eq 'edit') { # && 
         if ($preview) {
-            my $text = param('text') // '';
+            my $text = param('text');
+            $text = '' unless defined $text;
             $template->param(CONTENT=>Quiki::Formatter::format($self, $text));
             $template->param(TEXT => $text);
         }
